@@ -1,11 +1,13 @@
+from __future__ import annotations
+
 from functools import partial
 from typing import Any, Awaitable, Callable, Iterable, List, Tuple, TypeVar, Union, overload
 
 from typing_extensions import ParamSpec
 
 try:
-    from anyio import create_task_group  # type: ignore
-    from anyio.to_thread import run_sync as standard_run_blocking  # type: ignore
+    from anyio import create_task_group
+    from anyio.to_thread import run_sync as standard_run_blocking
 
 except ImportError:
     CONCURRENT = False
@@ -13,7 +15,7 @@ except ImportError:
 else:
     CONCURRENT = True
 
-from iters.typing import AnyException, DynamicTuple, EmptyTuple, is_error
+from iters.typing import AnyException, DynamicTuple, EmptyTuple, is_any_exception
 
 __all__ = (
     "CONCURRENT",
@@ -75,7 +77,7 @@ async def _append_tagged_result(
 
 
 def unwrap_result(result: AnyResult[T]) -> T:
-    if is_error(result):
+    if is_any_exception(result):
         raise result
 
     return result  # type: ignore
@@ -286,6 +288,7 @@ if CONCURRENT:
         __awaitable_f: Awaitable[Any],
         __awaitable_g: Awaitable[Any],
         __awaitable_h: Awaitable[Any],
+        __awaitable_next: Awaitable[Any],
         *awaitables: Awaitable[Any],
     ) -> DynamicTuple[Any]:
         ...
@@ -297,4 +300,4 @@ if CONCURRENT:
         return list(map(unwrap_result, await collect_iterable_with_errors(iterable)))
 
     async def run_blocking(function: Callable[P, T], *args: P.args, **kwargs: P.kwargs) -> T:
-        return await standard_run_blocking(partial(function, *args, **kwargs))  # type: ignore
+        return await standard_run_blocking(partial(function, *args, **kwargs))
