@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from builtins import zip as standard_zip
 from collections import Counter as counter_dict
 from collections import deque
@@ -39,16 +41,15 @@ from typing import (
     overload,
 )
 
+from orderings import LenientOrdered, Ordering, StrictOrdered
 from typing_extensions import Literal, Never, TypeVarTuple, Unpack
 
-from iters.types import Ordering, marker, no_default
+from iters.types import marker, no_default
 from iters.typing import (
     AnyExceptionType,
     Binary,
     Compare,
     DynamicTuple,
-    EitherLenientOrdered,
-    EitherStrictOrdered,
     EmptyTuple,
     Nullary,
     Predicate,
@@ -195,6 +196,7 @@ __all__ = (
     "zip_longest",
 )
 
+PYTHON_3_8 = version_info >= (3, 8, 0)
 PYTHON_3_10 = version_info >= (3, 10, 0)
 
 T = TypeVar("T")
@@ -220,8 +222,8 @@ Q = TypeVar("Q", bound=Hashable)
 S = TypeVar("S", bound=Sum)
 P = TypeVar("P", bound=Product)
 
-LT = TypeVar("LT", bound=EitherLenientOrdered)
-ST = TypeVar("ST", bound=EitherStrictOrdered)
+LT = TypeVar("LT", bound=LenientOrdered)
+ST = TypeVar("ST", bound=StrictOrdered)
 
 chain_from_iterable = chain.from_iterable
 skip_while = drop_while
@@ -229,12 +231,12 @@ skip_while = drop_while
 
 @overload
 def compare(left_iterable: Iterable[ST], right_iterable: Iterable[ST], key: None = ...) -> Ordering:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def compare(left_iterable: Iterable[T], right_iterable: Iterable[T], key: Unary[T, ST]) -> Ordering:
-    ...  # pragma: overload
+    ...
 
 
 def compare(
@@ -256,10 +258,10 @@ def compare_simple(left_iterable: Iterable[ST], right_iterable: Iterable[ST]) ->
         if right is marker:
             return Ordering.GREATER
 
-        if left < right:  # type: ignore  # investigate
+        if left < right:  # type: ignore
             return Ordering.LESS
 
-        if left > right:  # type: ignore  # investigate
+        if left > right:  # type: ignore
             return Ordering.GREATER
 
     return Ordering.EQUAL
@@ -321,12 +323,12 @@ def repeat_each(iterable: Iterable[T], count: int = 2) -> Iterator[T]:
 
 @overload
 def repeat_last(iterable: Iterable[T]) -> Iterator[T]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def repeat_last(iterable: Iterable[T], default: U) -> Iterator[Union[T, U]]:
-    ...  # pragma: overload
+    ...
 
 
 def repeat_last(iterable: Iterable[Any], default: Any = no_default) -> Iterator[Any]:
@@ -362,12 +364,12 @@ FIRST_ON_EMPTY = "first() called on an empty iterable"
 
 @overload
 def first(iterable: Iterable[T]) -> T:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def first(iterable: Iterable[T], default: U) -> Union[T, U]:
-    ...  # pragma: overload
+    ...
 
 
 def first(iterable: Iterable[Any], default: Any = no_default) -> Any:
@@ -389,12 +391,12 @@ LAST_ON_EMPTY = "last() called on an empty iterable"
 
 @overload
 def last(iterable: Iterable[T]) -> T:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def last(iterable: Iterable[T], default: U) -> Union[T, U]:
-    ...  # pragma: overload
+    ...
 
 
 def last(iterable: Iterable[Any], default: Any = no_default) -> Any:
@@ -487,17 +489,20 @@ def accumulate_reduce(function: Binary[T, T, T], iterable: Iterable[T]) -> Itera
 
 
 def accumulate_fold(initial: U, function: Binary[U, T, U], iterable: Iterable[T]) -> Iterator[U]:
-    return standard_accumulate(iterable, function, initial=initial)
+    if PYTHON_3_8:
+        return standard_accumulate(iterable, function, initial=initial)  # type: ignore
+
+    return standard_accumulate(prepend(initial, iterable), function)  # type: ignore
 
 
 @overload
 def accumulate_sum(iterable: Iterable[S]) -> Iterator[S]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def accumulate_sum(iterable: Iterable[S], initial: S) -> Iterator[S]:
-    ...  # pragma: overload
+    ...
 
 
 def accumulate_sum(iterable: Iterable[Any], initial: Any = no_default) -> Iterator[Any]:
@@ -509,12 +514,12 @@ def accumulate_sum(iterable: Iterable[Any], initial: Any = no_default) -> Iterat
 
 @overload
 def accumulate_product(iterable: Iterable[P]) -> Iterator[P]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def accumulate_product(iterable: Iterable[P], initial: P) -> Iterator[P]:
-    ...  # pragma: overload
+    ...
 
 
 def accumulate_product(iterable: Iterable[Any], initial: Any = no_default) -> Iterator[Any]:
@@ -529,12 +534,12 @@ AT_ON_EMPTY = "at() called on an empty iterable"
 
 @overload
 def at(index: int, iterable: Iterable[T]) -> T:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def at(index: int, iterable: Iterable[T], default: U) -> Union[T, U]:
-    ...  # pragma: overload
+    ...
 
 
 def at(index: int, iterable: Iterable[Any], default: Any = no_default) -> Any:
@@ -556,12 +561,12 @@ AT_OR_LAST_ON_EMPTY = "at_or_last() called on an empty iterable"
 
 @overload
 def at_or_last(index: int, iterable: Iterable[T]) -> T:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def at_or_last(index: int, iterable: Iterable[T], default: U) -> Union[T, U]:
-    ...  # pragma: overload
+    ...
 
 
 def at_or_last(index: int, iterable: Iterable[Any], default: Any = no_default) -> Any:
@@ -580,57 +585,57 @@ def at_or_last(index: int, iterable: Iterable[Any], default: Any = no_default) -
 
 @overload
 def copy_unsafe(iterable: Iterable[T]) -> Tuple[Iterator[T], Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy_unsafe(iterable: Iterable[T], copies: Literal[0]) -> EmptyTuple:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy_unsafe(iterable: Iterable[T], copies: Literal[1]) -> Tuple1[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy_unsafe(iterable: Iterable[T], copies: Literal[2]) -> Tuple2[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy_unsafe(iterable: Iterable[T], copies: Literal[3]) -> Tuple3[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy_unsafe(iterable: Iterable[T], copies: Literal[4]) -> Tuple4[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy_unsafe(iterable: Iterable[T], copies: Literal[5]) -> Tuple5[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy_unsafe(iterable: Iterable[T], copies: Literal[6]) -> Tuple6[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy_unsafe(iterable: Iterable[T], copies: Literal[7]) -> Tuple7[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy_unsafe(iterable: Iterable[T], copies: Literal[8]) -> Tuple8[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy_unsafe(iterable: Iterable[T], copies: int) -> DynamicTuple[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 def copy_unsafe(iterable: Iterable[T], copies: int = 2) -> DynamicTuple[Iterator[T]]:
@@ -642,57 +647,57 @@ copy_infinite = copy_unsafe
 
 @overload
 def copy(iterable: Iterable[T]) -> Tuple[Iterator[T], Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy(iterable: Iterable[T], copies: Literal[0]) -> EmptyTuple:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy(iterable: Iterable[T], copies: Literal[1]) -> Tuple1[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy(iterable: Iterable[T], copies: Literal[2]) -> Tuple2[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy(iterable: Iterable[T], copies: Literal[3]) -> Tuple3[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy(iterable: Iterable[T], copies: Literal[4]) -> Tuple4[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy(iterable: Iterable[T], copies: Literal[5]) -> Tuple5[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy(iterable: Iterable[T], copies: Literal[6]) -> Tuple6[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy(iterable: Iterable[T], copies: Literal[7]) -> Tuple7[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy(iterable: Iterable[T], copies: Literal[8]) -> Tuple8[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def copy(iterable: Iterable[T], copies: int) -> DynamicTuple[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 def copy(iterable: Iterable[T], copies: int = 2) -> DynamicTuple[Iterator[T]]:
@@ -718,52 +723,52 @@ def step_by(step: int, iterable: Iterable[T]) -> Iterator[T]:
 
 @overload
 def groups(size: Literal[0], iterable: Iterable[T]) -> Iterator[Never]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups(size: Literal[1], iterable: Iterable[T]) -> Iterator[Tuple1[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups(size: Literal[2], iterable: Iterable[T]) -> Iterator[Tuple2[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups(size: Literal[3], iterable: Iterable[T]) -> Iterator[Tuple3[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups(size: Literal[4], iterable: Iterable[T]) -> Iterator[Tuple4[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups(size: Literal[5], iterable: Iterable[T]) -> Iterator[Tuple5[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups(size: Literal[6], iterable: Iterable[T]) -> Iterator[Tuple6[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups(size: Literal[7], iterable: Iterable[T]) -> Iterator[Tuple7[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups(size: Literal[8], iterable: Iterable[T]) -> Iterator[Tuple8[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups(size: int, iterable: Iterable[T]) -> Iterator[DynamicTuple[T]]:
-    ...  # pragma: overload
+    ...
 
 
 def groups(size: int, iterable: Iterable[T]) -> Iterator[DynamicTuple[T]]:
@@ -772,118 +777,118 @@ def groups(size: int, iterable: Iterable[T]) -> Iterator[DynamicTuple[T]]:
 
 @overload
 def groups_longest(size: Literal[0], iterable: Iterable[T]) -> Iterator[Never]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(size: Literal[1], iterable: Iterable[T]) -> Iterator[Tuple1[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(size: Literal[2], iterable: Iterable[T]) -> Iterator[Tuple2[Optional[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(size: Literal[3], iterable: Iterable[T]) -> Iterator[Tuple3[Optional[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(size: Literal[4], iterable: Iterable[T]) -> Iterator[Tuple4[Optional[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(size: Literal[5], iterable: Iterable[T]) -> Iterator[Tuple5[Optional[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(size: Literal[6], iterable: Iterable[T]) -> Iterator[Tuple6[Optional[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(size: Literal[7], iterable: Iterable[T]) -> Iterator[Tuple7[Optional[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(size: Literal[8], iterable: Iterable[T]) -> Iterator[Tuple8[Optional[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(size: int, iterable: Iterable[T]) -> Iterator[DynamicTuple[Optional[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(size: Literal[0], iterable: Iterable[T], fill: U) -> Iterator[Never]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(size: Literal[1], iterable: Iterable[T], fill: U) -> Iterator[Tuple1[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(
     size: Literal[2], iterable: Iterable[T], fill: U
 ) -> Iterator[Tuple2[Union[T, U]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(
     size: Literal[3], iterable: Iterable[T], fill: U
 ) -> Iterator[Tuple3[Union[T, U]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(
     size: Literal[4], iterable: Iterable[T], fill: U
 ) -> Iterator[Tuple4[Union[T, U]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(
     size: Literal[5], iterable: Iterable[T], fill: U
 ) -> Iterator[Tuple5[Union[T, U]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(
     size: Literal[6], iterable: Iterable[T], fill: U
 ) -> Iterator[Tuple6[Union[T, U]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(
     size: Literal[7], iterable: Iterable[T], fill: U
 ) -> Iterator[Tuple7[Union[T, U]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(
     size: Literal[8], iterable: Iterable[T], fill: U
 ) -> Iterator[Tuple8[Union[T, U]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def groups_longest(
     size: int, iterable: Iterable[T], fill: U
 ) -> Iterator[DynamicTuple[Union[T, U]]]:
-    ...  # pragma: overload
+    ...
 
 
 def groups_longest(
@@ -894,12 +899,12 @@ def groups_longest(
 
 @overload
 def pairs_longest(iterable: Iterable[T]) -> Iterator[Tuple[Optional[T], Optional[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def pairs_longest(iterable: Iterable[T], fill: U) -> Iterator[Tuple[Union[T, U], Union[T, U]]]:
-    ...  # pragma: overload
+    ...
 
 
 def pairs_longest(iterable: Iterable[Any], fill: Optional[Any] = None) -> Iterator[Tuple[Any, Any]]:
@@ -957,7 +962,9 @@ def partition_unsafe(
 partition_infinite = partition_unsafe
 
 
-def partition(predicate: Optional[Predicate[T]], iterable: Iterable[T]) -> Tuple[Iterator[T], Iterator[T]]:
+def partition(
+    predicate: Optional[Predicate[T]], iterable: Iterable[T]
+) -> Tuple[Iterator[T], Iterator[T]]:
     for_true, for_false = copy(iterable)
 
     return filter(predicate, for_true), filter_false(predicate, for_false)
@@ -973,12 +980,12 @@ def append(item: T, iterable: Iterable[T]) -> Iterator[T]:
 
 @overload
 def group(iterable: Iterable[T], key: None = ...) -> Iterator[Tuple[T, Iterator[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def group(iterable: Iterable[T], key: Unary[T, U]) -> Iterator[Tuple[U, Iterator[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 def group(
@@ -989,12 +996,12 @@ def group(
 
 @overload
 def group_list(iterable: Iterable[T], key: None = ...) -> Iterator[Tuple[T, List[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def group_list(iterable: Iterable[T], key: Unary[T, U]) -> Iterator[Tuple[U, List[T]]]:
-    ...  # pragma: overload
+    ...
 
 
 def group_list(
@@ -1006,12 +1013,12 @@ def group_list(
 
 @overload
 def group_dict(iterable: Iterable[Q], key: None = ...) -> Dict[Q, List[Q]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def group_dict(iterable: Iterable[T], key: Unary[T, Q]) -> Dict[Q, List[T]]:
-    ...  # pragma: overload
+    ...
 
 
 def group_dict(
@@ -1027,12 +1034,12 @@ def group_dict(
 
 @overload
 def count_dict(iterable: Iterable[Q], key: None = ...) -> Counter[Q]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def count_dict(iterable: Iterable[T], key: Unary[T, Q]) -> Counter[Q]:
-    ...  # pragma: overload
+    ...
 
 
 def count_dict(iterable: Iterable[Any], key: Optional[Unary[Any, Any]] = None) -> Counter[Any]:
@@ -1096,12 +1103,12 @@ def iter_length(iterable: Iterable[T]) -> int:
 
 @overload
 def sum(iterable: Iterable[S]) -> S:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def sum(iterable: Iterable[S], initial: S) -> S:
-    ...  # pragma: overload
+    ...
 
 
 def sum(iterable: Iterable[Any], initial: Any = no_default) -> Any:
@@ -1113,12 +1120,12 @@ def sum(iterable: Iterable[Any], initial: Any = no_default) -> Any:
 
 @overload
 def product(iterable: Iterable[P]) -> P:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def product(iterable: Iterable[P], initial: P) -> P:
-    ...  # pragma: overload
+    ...
 
 
 def product(iterable: Iterable[Any], initial: Any = no_default) -> Any:
@@ -1225,12 +1232,12 @@ def contains_identity(value: T, iterable: Iterable[T]) -> bool:
 
 @overload
 def all_unique_fast(iterable: Iterable[Q], key: None = ...) -> bool:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def all_unique_fast(iterable: Iterable[T], key: Unary[T, Q]) -> bool:
-    ...  # pragma: overload
+    ...
 
 
 def all_unique_fast(iterable: Iterable[Any], key: Optional[Unary[Any, Any]] = None) -> bool:
@@ -1278,12 +1285,12 @@ PEEK_ON_EMPTY = "peek() called on an empty iterable"
 
 @overload
 def peek(iterable: Iterable[T]) -> Tuple[T, Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def peek(iterable: Iterable[T], default: U) -> Tuple[Union[T, U], Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 def peek(iterable: Iterable[Any], default: Any = no_default) -> Tuple[Any, Iterator[Any]]:
@@ -1340,52 +1347,52 @@ def combine(*iterables: Iterable[T]) -> Iterator[T]:
 
 @overload
 def distribute_unsafe(count: Literal[0], iterable: Iterable[T]) -> EmptyTuple:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute_unsafe(count: Literal[1], iterable: Iterable[T]) -> Tuple1[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute_unsafe(count: Literal[2], iterable: Iterable[T]) -> Tuple2[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute_unsafe(count: Literal[3], iterable: Iterable[T]) -> Tuple3[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute_unsafe(count: Literal[4], iterable: Iterable[T]) -> Tuple4[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute_unsafe(count: Literal[5], iterable: Iterable[T]) -> Tuple5[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute_unsafe(count: Literal[6], iterable: Iterable[T]) -> Tuple6[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute_unsafe(count: Literal[7], iterable: Iterable[T]) -> Tuple7[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute_unsafe(count: Literal[8], iterable: Iterable[T]) -> Tuple8[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute_unsafe(count: int, iterable: Iterable[T]) -> DynamicTuple[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 def distribute_unsafe(count: int, iterable: Iterable[T]) -> DynamicTuple[Iterator[T]]:
@@ -1399,52 +1406,52 @@ distribute_infinite = distribute_unsafe
 
 @overload
 def distribute(count: Literal[0], iterable: Iterable[T]) -> EmptyTuple:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute(count: Literal[1], iterable: Iterable[T]) -> Tuple1[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute(count: Literal[2], iterable: Iterable[T]) -> Tuple2[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute(count: Literal[3], iterable: Iterable[T]) -> Tuple3[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute(count: Literal[4], iterable: Iterable[T]) -> Tuple4[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute(count: Literal[5], iterable: Iterable[T]) -> Tuple5[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute(count: Literal[6], iterable: Iterable[T]) -> Tuple6[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute(count: Literal[7], iterable: Iterable[T]) -> Tuple7[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute(count: Literal[8], iterable: Iterable[T]) -> Tuple8[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def distribute(count: int, iterable: Iterable[T]) -> DynamicTuple[Iterator[T]]:
-    ...  # pragma: overload
+    ...
 
 
 def distribute(count: int, iterable: Iterable[T]) -> DynamicTuple[Iterator[T]]:
@@ -1508,15 +1515,17 @@ POSITION_NO_MATCH = "position() has not found any matches"
 
 @overload
 def position(predicate: Optional[Predicate[T]], iterable: Iterable[T]) -> int:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def position(predicate: Optional[Predicate[T]], iterable: Iterable[T], default: U) -> Union[int, U]:
-    ...  # pragma: overload
+    ...
 
 
-def position(predicate: Optional[Predicate[T]], iterable: Iterable[T], default: Any = no_default) -> Any:
+def position(
+    predicate: Optional[Predicate[T]], iterable: Iterable[T], default: Any = no_default
+) -> Any:
     index = next(position_all(predicate, iterable), None)
 
     if index is None:
@@ -1538,15 +1547,17 @@ FIND_ON_EMPTY = "find() called on an empty iterable"
 
 @overload
 def find(predicate: Optional[Predicate[T]], iterable: Iterable[T]) -> T:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def find(predicate: Optional[Predicate[T]], iterable: Iterable[T], default: U) -> Union[T, U]:
-    ...  # pragma: overload
+    ...
 
 
-def find(predicate: Optional[Predicate[Any]], iterable: Iterable[Any], default: Any = no_default) -> Any:
+def find(
+    predicate: Optional[Predicate[Any]], iterable: Iterable[Any], default: Any = no_default
+) -> Any:
     item = marker
 
     if predicate is None:
@@ -1570,12 +1581,14 @@ FIND_OR_FIRST_ON_EMPTY = "find_or_first() called on an empty iterable"
 
 @overload
 def find_or_first(predicate: Optional[Predicate[T]], iterable: Iterable[T]) -> T:
-    ...  # pragma: overload
+    ...
 
 
 @overload
-def find_or_first(predicate: Optional[Predicate[T]], iterable: Iterable[T], default: U) -> Union[T, U]:
-    ...  # pragma: overload
+def find_or_first(
+    predicate: Optional[Predicate[T]], iterable: Iterable[T], default: U
+) -> Union[T, U]:
+    ...
 
 
 def find_or_first(
@@ -1611,12 +1624,14 @@ FIND_OR_LAST_ON_EMPTY = "find_or_last() called on an empty iterable"
 
 @overload
 def find_or_last(predicate: Optional[Predicate[T]], iterable: Iterable[T]) -> T:
-    ...  # pragma: overload
+    ...
 
 
 @overload
-def find_or_last(predicate: Optional[Predicate[T]], iterable: Iterable[T], default: U) -> Union[T, U]:
-    ...  # pragma: overload
+def find_or_last(
+    predicate: Optional[Predicate[T]], iterable: Iterable[T], default: U
+) -> Union[T, U]:
+    ...
 
 
 def find_or_last(
@@ -1695,10 +1710,10 @@ def min_max_simple(iterable: Iterable[ST], value: ST) -> Tuple[ST, ST]:
     low = high = value
 
     for item in iterable:
-        if item < low:  # type: ignore  # investigate
+        if item < low:  # type: ignore
             low = item
 
-        if high < item:  # type: ignore  # investigate
+        if high < item:  # type: ignore
             high = item
 
     return (low, high)
@@ -1761,12 +1776,12 @@ LAST_WITH_TAIL_ON_EMPTY = "last_with_tail() called on an empty iterable"
 
 @overload
 def last_with_tail(iterable: Iterable[T]) -> T:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def last_with_tail(iterable: Iterable[T], default: U) -> Union[T, U]:
-    ...  # pragma: overload
+    ...
 
 
 def last_with_tail(iterable: Iterable[Any], default: Any = no_default) -> Any:
@@ -1797,7 +1812,10 @@ REVERSE_TRUE = True
 REVERSE_FALSE = False
 
 
-COMPARE: Dict[Tuple[bool, bool], Union[Compare[LT, LT], Compare[ST, ST]]] = {  # type: ignore
+COMPARE: Dict[
+    Tuple[bool, bool],
+    Union[Compare[LenientOrdered, LenientOrdered], Compare[StrictOrdered, StrictOrdered]],
+] = {
     (STRICT_FALSE, REVERSE_FALSE): less_or_equal,
     (STRICT_FALSE, REVERSE_TRUE): greater_or_equal,
     (STRICT_TRUE, REVERSE_FALSE): less,
@@ -1813,7 +1831,7 @@ def is_sorted(
     strict: Literal[False] = ...,
     reverse: bool = ...,
 ) -> bool:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -1824,7 +1842,7 @@ def is_sorted(
     strict: Literal[True],
     reverse: bool = ...,
 ) -> bool:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -1835,7 +1853,7 @@ def is_sorted(
     strict: Literal[False] = ...,
     reverse: bool = ...,
 ) -> bool:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -1846,7 +1864,7 @@ def is_sorted(
     strict: Literal[True],
     reverse: bool = ...,
 ) -> bool:
-    ...  # pragma: overload
+    ...
 
 
 def is_sorted(
@@ -1856,16 +1874,17 @@ def is_sorted(
     strict: bool = False,
     reverse: bool = False,
 ) -> bool:
-    if key is None:
-        return is_sorted_simple(iterable, strict=strict, reverse=reverse)
-
-    return is_sorted_by(iterable, key, strict=strict, reverse=reverse)
+    return (
+        is_sorted_simple(iterable, strict=strict, reverse=reverse)
+        if key is None
+        else is_sorted_by(iterable, key, strict=strict, reverse=reverse)
+    )
 
 
 def is_sorted_simple(
     iterable: Iterable[Any], *, strict: bool = False, reverse: bool = False
 ) -> bool:
-    compare = COMPARE[(strict, reverse)]
+    compare = COMPARE[strict, reverse]
     return all(map(unpack_binary(compare), pairs_windows(iterable)))
 
 
@@ -1877,12 +1896,12 @@ def is_sorted_by(
 
 @overload
 def sort(iterable: Iterable[ST], *, key: None = ..., reverse: bool = ...) -> Iterator[ST]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def sort(iterable: Iterable[T], *, key: Unary[T, ST], reverse: bool = ...) -> Iterator[T]:
-    ...  # pragma: overload
+    ...
 
 
 def sort(
@@ -1919,56 +1938,64 @@ def list_windows(size: int, iterable: Iterable[T]) -> Iterator[List[T]]:
 
 @overload
 def tuple_windows(size: Literal[0], iterable: Iterable[T]) -> Iterator[EmptyTuple]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def tuple_windows(size: Literal[1], iterable: Iterable[T]) -> Iterator[Tuple1[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def tuple_windows(size: Literal[2], iterable: Iterable[T]) -> Iterator[Tuple2[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def tuple_windows(size: Literal[3], iterable: Iterable[T]) -> Iterator[Tuple3[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def tuple_windows(size: Literal[4], iterable: Iterable[T]) -> Iterator[Tuple4[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def tuple_windows(size: Literal[5], iterable: Iterable[T]) -> Iterator[Tuple5[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def tuple_windows(size: Literal[6], iterable: Iterable[T]) -> Iterator[Tuple6[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def tuple_windows(size: Literal[7], iterable: Iterable[T]) -> Iterator[Tuple7[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def tuple_windows(size: Literal[8], iterable: Iterable[T]) -> Iterator[Tuple8[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def tuple_windows(size: int, iterable: Iterable[T]) -> Iterator[DynamicTuple[T]]:
-    ...  # pragma: overload
+    ...
 
 
 def tuple_windows(size: int, iterable: Iterable[T]) -> Iterator[DynamicTuple[T]]:
-    for window in list_windows(size, iterable):
+    iterator = iter(iterable)
+
+    window = deque(take(size, iterator), size)
+
+    if len(window) == size:
+        yield tuple(window)
+
+    for item in iterator:
+        window.append(item)
         yield tuple(window)
 
 
@@ -1981,7 +2008,20 @@ def iter_windows(size: int, iterable: Iterable[T]) -> Iterator[Iterator[T]]:
         yield iter(window)
 
 
-def side_effect(function: Unary[T, Any], iterable: Iterable[T]) -> Iterator[T]:
+def set_windows(size: int, iterable: Iterable[Q]) -> Iterator[Set[Q]]:
+    iterator = iter(iterable)
+
+    window = deque(take(size, iterator), size)
+
+    if len(window) == size:
+        yield set(window)
+
+    for item in iterator:
+        window.append(item)
+        yield set(window)
+
+
+def side_effect(function: Unary[T, None], iterable: Iterable[T]) -> Iterator[T]:
     for item in iterable:
         function(item)
         yield item
@@ -2015,12 +2055,12 @@ def duplicates_fast_by(iterable: Iterable[T], key: Unary[T, Q]) -> Iterator[T]:
 
 @overload
 def duplicates_fast(iterable: Iterable[Q], key: None = ...) -> Iterator[Q]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def duplicates_fast(iterable: Iterable[T], key: Unary[T, Q]) -> Iterator[T]:
-    ...  # pragma: overload
+    ...
 
 
 def duplicates_fast(
@@ -2105,12 +2145,12 @@ def unique_fast_by(iterable: Iterable[T], key: Unary[T, Q]) -> Iterator[T]:
 
 @overload
 def unique_fast(iterable: Iterable[Q], key: None = ...) -> Iterator[Q]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def unique_fast(iterable: Iterable[T], key: Unary[T, Q]) -> Iterator[T]:
-    ...  # pragma: overload
+    ...
 
 
 def unique_fast(iterable: Iterable[Any], key: Optional[Unary[Any, Any]] = None) -> Iterator[Any]:
@@ -2165,24 +2205,24 @@ def unique(iterable: Iterable[T], key: Optional[Unary[T, U]] = None) -> Iterator
 
 @overload
 def zip() -> Iterator[Never]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def zip(__iterable_a: Iterable[A]) -> Iterator[Tuple[A]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def zip(__iterable_a: Iterable[A], __iterable_b: Iterable[B]) -> Iterator[Tuple[A, B]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def zip(
     __iterable_a: Iterable[A], __iterable_b: Iterable[B], __iterable_c: Iterable[C]
 ) -> Iterator[Tuple[A, B, C]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2192,7 +2232,7 @@ def zip(
     __iterable_c: Iterable[C],
     __iterable_d: Iterable[D],
 ) -> Iterator[Tuple[A, B, C, D]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2203,7 +2243,7 @@ def zip(
     __iterable_d: Iterable[D],
     __iterable_e: Iterable[E],
 ) -> Iterator[Tuple[A, B, C, D, E]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2215,7 +2255,7 @@ def zip(
     __iterable_e: Iterable[E],
     __iterable_f: Iterable[F],
 ) -> Iterator[Tuple[A, B, C, D, E, F]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2228,7 +2268,7 @@ def zip(
     __iterable_f: Iterable[F],
     __iterable_g: Iterable[G],
 ) -> Iterator[Tuple[A, B, C, D, E, F, G]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2242,7 +2282,7 @@ def zip(
     __iterable_g: Iterable[G],
     __iterable_h: Iterable[H],
 ) -> Iterator[Tuple[A, B, C, D, E, F, G, H]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2258,7 +2298,7 @@ def zip(
     __iterable_next: Iterable[Any],
     *iterables: Iterable[Any],
 ) -> Iterator[DynamicTuple[Any]]:
-    ...  # pragma: overload
+    ...
 
 
 def zip(*iterables: Iterable[Any]) -> Iterator[DynamicTuple[Any]]:
@@ -2267,24 +2307,24 @@ def zip(*iterables: Iterable[Any]) -> Iterator[DynamicTuple[Any]]:
 
 @overload
 def zip_equal() -> Iterator[Never]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def zip_equal(__iterable_a: Iterable[A]) -> Iterator[Tuple[A]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def zip_equal(__iterable_a: Iterable[A], __iterable_b: Iterable[B]) -> Iterator[Tuple[A, B]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def zip_equal(
     __iterable_a: Iterable[A], __iterable_b: Iterable[B], __iterable_c: Iterable[C]
 ) -> Iterator[Tuple[A, B, C]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2294,7 +2334,7 @@ def zip_equal(
     __iterable_c: Iterable[C],
     __iterable_d: Iterable[D],
 ) -> Iterator[Tuple[A, B, C, D]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2305,7 +2345,7 @@ def zip_equal(
     __iterable_d: Iterable[D],
     __iterable_e: Iterable[E],
 ) -> Iterator[Tuple[A, B, C, D, E]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2317,7 +2357,7 @@ def zip_equal(
     __iterable_e: Iterable[E],
     __iterable_f: Iterable[F],
 ) -> Iterator[Tuple[A, B, C, D, E, F]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2330,7 +2370,7 @@ def zip_equal(
     __iterable_f: Iterable[F],
     __iterable_g: Iterable[G],
 ) -> Iterator[Tuple[A, B, C, D, E, F, G]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2344,7 +2384,7 @@ def zip_equal(
     __iterable_g: Iterable[G],
     __iterable_h: Iterable[H],
 ) -> Iterator[Tuple[A, B, C, D, E, F, G, H]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2360,12 +2400,12 @@ def zip_equal(
     __iterable_next: Iterable[Any],
     *iterables: Iterable[Any],
 ) -> Iterator[DynamicTuple[Any]]:
-    ...  # pragma: overload
+    ...
 
 
 def zip_equal(*iterables: Iterable[Any]) -> Iterator[DynamicTuple[Any]]:
     if PYTHON_3_10:
-        return standard_zip(*iterables, strict=True)
+        return standard_zip(*iterables, strict=True)  # type: ignore
 
     return zip_equal_simple(*iterables)
 
@@ -2415,19 +2455,19 @@ def zip_equal_simple(*iterables: Iterable[Any]) -> Iterator[DynamicTuple[Any]]:
 
 @overload
 def zip_longest() -> Iterator[Never]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def zip_longest(__iterable_a: Iterable[A]) -> Iterator[Tuple[A]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def zip_longest(
     __iterable_a: Iterable[A], __iterable_b: Iterable[B]
 ) -> Iterator[Tuple[Optional[A], Optional[B]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2436,7 +2476,7 @@ def zip_longest(
     __iterable_b: Iterable[B],
     __iterable_c: Iterable[C],
 ) -> Iterator[Tuple[Optional[A], Optional[B], Optional[C]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2446,7 +2486,7 @@ def zip_longest(
     __iterable_c: Iterable[C],
     __iterable_d: Iterable[D],
 ) -> Iterator[Tuple[Optional[A], Optional[B], Optional[C], Optional[D]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2457,7 +2497,7 @@ def zip_longest(
     __iterable_d: Iterable[D],
     __iterable_e: Iterable[E],
 ) -> Iterator[Tuple[Optional[A], Optional[B], Optional[C], Optional[D], Optional[E]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2469,7 +2509,7 @@ def zip_longest(
     __iterable_e: Iterable[E],
     __iterable_f: Iterable[F],
 ) -> Iterator[Tuple[Optional[A], Optional[B], Optional[C], Optional[D], Optional[E], Optional[F]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2492,7 +2532,7 @@ def zip_longest(
         Optional[G],
     ]
 ]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2517,7 +2557,7 @@ def zip_longest(
         Optional[H],
     ]
 ]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2533,24 +2573,24 @@ def zip_longest(
     __iterable_next: Iterable[Any],
     *iterables: Iterable[Any],
 ) -> Iterator[DynamicTuple[Optional[Any]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def zip_longest(*, fill: T) -> Iterator[Never]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def zip_longest(__iterable_a: Iterable[A], *, fill: T) -> Iterator[Tuple[A]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def zip_longest(
     __iterable_a: Iterable[A], __iterable_b: Iterable[B], *, fill: T
 ) -> Iterator[Tuple[Union[A, T], Union[B, T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2561,7 +2601,7 @@ def zip_longest(
     *,
     fill: T,
 ) -> Iterator[Tuple[Union[A, T], Union[B, T], Union[C, T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2573,7 +2613,7 @@ def zip_longest(
     *,
     fill: T,
 ) -> Iterator[Tuple[Union[A, T], Union[B, T], Union[C, T], Union[D, T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2586,7 +2626,7 @@ def zip_longest(
     *,
     fill: T,
 ) -> Iterator[Tuple[Union[A, T], Union[B, T], Union[C, T], Union[D, T], Union[E, T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2600,7 +2640,7 @@ def zip_longest(
     *,
     fill: T,
 ) -> Iterator[Tuple[Union[A, T], Union[B, T], Union[C, T], Union[D, T], Union[E, T], Union[F, T]]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2625,7 +2665,7 @@ def zip_longest(
         Union[G, T],
     ]
 ]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2652,7 +2692,7 @@ def zip_longest(
         Union[H, T],
     ]
 ]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2669,7 +2709,7 @@ def zip_longest(
     *iterables: Iterable[Any],
     fill: T,
 ) -> Iterator[DynamicTuple[Union[Any, T]]]:
-    ...  # pragma: overload
+    ...
 
 
 def zip_longest(
@@ -2680,26 +2720,26 @@ def zip_longest(
 
 @overload
 def cartesian_product() -> Iterator[EmptyTuple]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_product(__iterable_a: Iterable[A]) -> Iterator[Tuple[A]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_product(
     __iterable_a: Iterable[A], __iterable_b: Iterable[B]
 ) -> Iterator[Tuple[A, B]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_product(
     __iterable_a: Iterable[A], __iterable_b: Iterable[B], __iterable_c: Iterable[C]
 ) -> Iterator[Tuple[A, B, C]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2709,7 +2749,7 @@ def cartesian_product(
     __iterable_c: Iterable[C],
     __iterable_d: Iterable[D],
 ) -> Iterator[Tuple[A, B, C, D]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2720,7 +2760,7 @@ def cartesian_product(
     __iterable_d: Iterable[D],
     __iterable_e: Iterable[E],
 ) -> Iterator[Tuple[A, B, C, D, E]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2732,7 +2772,7 @@ def cartesian_product(
     __iterable_e: Iterable[E],
     __iterable_f: Iterable[F],
 ) -> Iterator[Tuple[A, B, C, D, E, F]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2745,7 +2785,7 @@ def cartesian_product(
     __iterable_f: Iterable[F],
     __iterable_g: Iterable[G],
 ) -> Iterator[Tuple[A, B, C, D, E, F, G]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2759,7 +2799,7 @@ def cartesian_product(
     __iterable_g: Iterable[G],
     __iterable_h: Iterable[H],
 ) -> Iterator[Tuple[A, B, C, D, E, F, G, H]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
@@ -2775,7 +2815,7 @@ def cartesian_product(
     __iterable_next: Iterable[Any],
     *iterables: Iterable[Any],
 ) -> Iterator[DynamicTuple[Any]]:
-    ...  # pragma: overload
+    ...
 
 
 def cartesian_product(*iterables: Iterable[Any]) -> Iterator[DynamicTuple[Any]]:
@@ -2784,52 +2824,52 @@ def cartesian_product(*iterables: Iterable[Any]) -> Iterator[DynamicTuple[Any]]:
 
 @overload
 def cartesian_power(power: Literal[0], iterable: Iterable[T]) -> Iterator[EmptyTuple]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_power(power: Literal[1], iterable: Iterable[T]) -> Iterator[Tuple1[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_power(power: Literal[2], iterable: Iterable[T]) -> Iterator[Tuple2[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_power(power: Literal[3], iterable: Iterable[T]) -> Iterator[Tuple3[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_power(power: Literal[4], iterable: Iterable[T]) -> Iterator[Tuple4[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_power(power: Literal[5], iterable: Iterable[T]) -> Iterator[Tuple5[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_power(power: Literal[6], iterable: Iterable[T]) -> Iterator[Tuple6[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_power(power: Literal[7], iterable: Iterable[T]) -> Iterator[Tuple7[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_power(power: Literal[8], iterable: Iterable[T]) -> Iterator[Tuple8[T]]:
-    ...  # pragma: overload
+    ...
 
 
 @overload
 def cartesian_power(power: int, iterable: Iterable[T]) -> Iterator[DynamicTuple[T]]:
-    ...  # pragma: overload
+    ...
 
 
 def cartesian_power(power: int, iterable: Iterable[T]) -> Iterator[DynamicTuple[T]]:
